==> zio-aws-memorydb_2.12-5.17.217.1-sources.jar: zio/aws/memorydb/model/Authentication.scala <==
package zio.aws.memorydb.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.memorydb.model.primitives.IntegerOptional
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class Authentication(
    `type`: Optional[zio.aws.memorydb.model.AuthenticationType] =
      Optional.Absent,
    passwordCount: Optional[IntegerOptional] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.Authentication = {
    import Authentication.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.Authentication
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(passwordCount.map(value => value: Integer))(
        _.passwordCount
      )
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.Authentication.ReadOnly =
    zio.aws.memorydb.model.Authentication.wrap(buildAwsValue())
}
object Authentication {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.Authentication
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.Authentication =
      zio.aws.memorydb.model.Authentication(
        `type`.map(value => value),
        passwordCount.map(value => value)
      )
    def `type`: Optional[zio.aws.memorydb.model.AuthenticationType]
    def passwordCount: Optional[IntegerOptional]
    def getType: ZIO[Any, AwsError, zio.aws.memorydb.model.AuthenticationType] =
      AwsError.unwrapOptionField("type", `type`)
    def getPasswordCount: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("passwordCount", passwordCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.Authentication
  ) extends zio.aws.memorydb.model.Authentication.ReadOnly {
    override val `type`: Optional[zio.aws.memorydb.model.AuthenticationType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.memorydb.model.AuthenticationType.wrap(value))
    override val passwordCount: Optional[IntegerOptional] =
      zio.aws.core.internal
        .optionalFromNullable(impl.passwordCount())
        .map(value => value: IntegerOptional)
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.Authentication
  ): zio.aws.memorydb.model.Authentication.ReadOnly = new Wrapper(impl)
}

==> zio-aws-memorydb_3-5.17.121.2-sources.jar: zio/aws/memorydb/model/Authentication.scala <==
package zio.aws.memorydb.model
import java.lang.Integer
import zio.ZIO
import zio.aws.memorydb.model.primitives.IntegerOptional
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Authentication(
    `type`: Option[zio.aws.memorydb.model.AuthenticationType] = None,
    passwordCount: Option[IntegerOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.Authentication = {
    import Authentication.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.Authentication
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(
        passwordCount.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.passwordCount)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.Authentication.ReadOnly =
    zio.aws.memorydb.model.Authentication.wrap(buildAwsValue())
}
object Authentication {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.Authentication
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.Authentication =
      zio.aws.memorydb.model.Authentication(
        `type`.map(value => value),
        passwordCount.map(value => value)
      )
    def `type`: Option[zio.aws.memorydb.model.AuthenticationType]
    def passwordCount: Option[IntegerOptional]
    def getType: ZIO[Any, AwsError, zio.aws.memorydb.model.AuthenticationType] =
      AwsError.unwrapOptionField("type", `type`)
    def getPasswordCount: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("passwordCount", passwordCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.Authentication
  ) extends zio.aws.memorydb.model.Authentication.ReadOnly {
    override val `type`: Option[zio.aws.memorydb.model.AuthenticationType] =
      scala
        .Option(impl.`type`())
        .map(value => zio.aws.memorydb.model.AuthenticationType.wrap(value))
    override val passwordCount: Option[IntegerOptional] = scala
      .Option(impl.passwordCount())
      .map(value => zio.aws.memorydb.model.primitives.IntegerOptional(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.Authentication
  ): zio.aws.memorydb.model.Authentication.ReadOnly = new Wrapper(impl)
}
